@@ -22,7 +22,7 @@ sub test_01_notifications : Test(2) {
     my $cli = Beekeeper::Client->instance;
     my $var = 74;
 
-    $SIG{'USR1'} = sub { $var = $var + 1 };
+    $SIG{'USR1'} = sub { $var++ };
 
     $cli->send_notification(
         method => "test.signal",
@@ -30,7 +30,7 @@ sub test_01_notifications : Test(2) {
     );
 
     my $expected = 76;
-    my $max_wait = 500; while ($max_wait--) { last if $var == $expected; sleep 0.01; }
+    my $max_wait = 10; while ($max_wait--) { sleep 0.5; last if $var == $expected }
     is( $var, $expected, "Notifications received by 2 workers");
 
     $cli->send_notification(
@@ -39,7 +39,7 @@ sub test_01_notifications : Test(2) {
     );
 
     $expected = 78;
-    $max_wait = 500; while ($max_wait--) { last if $var == $expected; sleep 0.01; }
+    $max_wait = 10; while ($max_wait--) { sleep 0.5; last if $var == $expected }
     is( $var, $expected, "Catchall notifications received by 2 workers");
 }
 
