@@ -103,7 +103,7 @@ sub test_01_shared_cache_basic : Test(11) {
 sub test_02_shared_cache_stress : Test(20) {
     my $self = shift;
 
-    if ($ENV{'AUTOMATED_TESTING'}) {
+    if ($ENV{'AUTOMATED_TESTING'} || $ENV{'PERL_BATCH'}) {
         # There is a chance of retrieving stale data from cache,
         # specially when broker is running low of CPU resources
         return "Shared cache stress tests are not deterministic";
